"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const upath_1 = require("upath");
const isbinaryfile_1 = require("isbinaryfile");
const File_1 = require("../core/File");
const Workspace_1 = require("../core/Workspace");
const RestClient_1 = require("../core/HTTP/RestClient");
const helpers_1 = require("../helpers");
async function shouldRewriteFile(resource, file, keepEncode) {
    const shasum = await file.getShaSum();
    if (shasum !== resource.checksum) {
        return true;
    }
    if (keepEncode && (await isbinaryfile_1.isBinaryFile(file.location))) {
        return true;
    }
    if (!keepEncode && file.isBase64Asset()) {
        await file.read();
        if (file.resource.contents.startsWith('data:')) {
            return true;
        }
    }
    return false;
}
exports.default = async (args) => {
    let workspace;
    let client;
    try {
        workspace = await Workspace_1.default.init(args.workspace, args.disableSSLVerification, args.ignoreSpecs);
    }
    catch (e) {
        return helpers_1.MissingWorkspaceError(args.workspace);
    }
    client = new RestClient_1.default(workspace.config, workspace.name);
    let response;
    try {
        response = await client.getAllFiles();
    }
    catch (e) {
        console.log(e);
        return;
    }
    let added = 0;
    let modified = 0;
    let specs = 0;
    if (response) {
        for (let resource of response) {
            if (workspace.config.ignoreSpecs && resource.path.startsWith('specs')) {
                specs++;
                continue;
            }
            let path = upath_1.join(workspace.path, resource.path);
            let file = new File_1.default(path, workspace.path);
            if (await file.exists()) {
                if (await shouldRewriteFile(resource, file, args.keepEncode)) {
                    file.write(resource.contents);
                    console.log('\t', 'Modified:', resource.path);
                    modified++;
                }
            }
            else {
                file.write(resource.contents);
                console.log('\t', 'Added:', resource.path);
                added++;
            }
        }
    }
    console.log('\t', `Fetched ${response.length} files`);
    if (specs) {
        console.log('\t', `Ignored ${specs} specs`);
    }
    if (!modified || added) {
        console.log('\t', 'No changes.');
    }
    console.log('');
    console.log('Done.');
};
