"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ora = require("ora");
const Workspace_1 = require("../core/Workspace");
const RestClient_1 = require("../core/HTTP/RestClient");
const helpers_1 = require("../helpers");
exports.default = async (args) => {
    let workspace;
    let client;
    try {
        workspace = await Workspace_1.default.init(args.workspace, args.disableSSLVerification, args.ignoreSpecs);
    }
    catch (e) {
        return helpers_1.MissingWorkspaceError(args.workspace);
    }
    client = new RestClient_1.default(workspace.config, workspace.name);
    let spinner = ora({
        prefixText: `Wiping...`,
        text: `reading files...`,
    }).start();
    let files;
    try {
        files = await client.getAllFiles();
        for (let file of files) {
            if (workspace.config.ignoreSpecs && file.path.startsWith('specs')) {
                continue;
            }
            spinner.text = file.path;
            await client.deleteFile(file);
        }
    }
    catch (e) {
        spinner.text = client.handleError(e);
        spinner.fail();
        return;
    }
    spinner.prefixText = `\t`;
    spinner.text = workspace.config.ignoreSpecs
        ? `Wiped all non-spec Files from ${workspace.name}`
        : `Wiped all Files from ${workspace.name}`;
    spinner.succeed();
};
